require 'spec_helper'

describe Paypal::Masspay::ResponseParser do
  let(:success_body)        { 'ACK=Success' }
  let(:fail_body)           { 'ACK=Failure&L_ERRORCODE0=10000&L_SHORTMESSAGE0=short_error_message&L_LONGMESSAGE0=long_error_message&L_SEVERITYCODE0=Error&L_ERRORCODE1=20000&L_SHORTMESSAGE1=short_error_message2&L_LONGMESSAGE1=long_error_message2&L_SEVERITYCODE1=Error' }
  let(:response_body)       { success_body }
  subject(:response_parser) { Paypal::Masspay::ResponseParser.new(response_body) }

  describe '#successful?' do
    context 'the response was successful' do
      let(:response_body) { success_body }

      it 'returns true' do
        expect(response_parser).to be_successful
      end
    end

    context 'the response was not successful' do
      let(:response_body) { fail_body }

      it 'returns false' do
        expect(response_parser).to_not be_successful
      end
    end
  end

  describe '#errors' do
    context 'the response was successful' do
      let(:response_body) { success_body }

      it 'has no errors' do
        expect(response_parser.errors.count).to eq(0)
      end
    end

    context 'the response was not successful' do
      let(:response_body) { fail_body }

      it 'has errors' do
        expect(response_parser.errors.count).to eq(2)
      end
    end
  end
end
